@@ -1,4 +1,4 @@
-/* $Id: defines.h,v 1.20 2001/11/19 09:23:52 kloczek Exp $ */
+/* $Id: defines.h,v 1.21 2003/05/03 16:14:23 kloczek Exp $ */
 /* some useful defines */
 
 #ifndef _DEFINES_H_
@@ -47,14 +47,6 @@ char *strchr(), *strrchr(), *strtok();
 # include <errno.h>
 #endif
 
-/* Solaris 2.4 defines __SVR4, but not SVR4 -j. */
-
-#ifdef __SVR4
-# ifndef SVR4
-#  define SVR4 __SVR4
-# endif
-#endif
-
 #include <sys/stat.h>
 #include <sys/types.h>
 #if HAVE_SYS_WAIT_H
@@ -283,7 +275,7 @@ char *strchr(), *strrchr(), *strtok();
 /* get rid of a few ugly repeated #ifdefs in pwent.c and grent.c */
 /* XXX - this is ugly too, configure should test it and not check for
    any hardcoded system names, if possible.  --marekm */
-#if defined(SVR4) || defined(AIX) || defined(__linux__)
+#if defined(AIX) || defined(__linux__)
 #define SETXXENT_TYPE void
 #define SETXXENT_RET(x) return
 #define SETXXENT_TEST(x) x; if (0) /* compiler should optimize this away */
